=======
CHANGES
=======

0.0.5 (2019-04-08)
------------------

- Manages cookies and prepare them for you so you don't have to create cookie
  headers by yourself using the ``auth=('username', 'password')``


0.0.4 (2019-01-25)
------------------

- Supports new pytest-play >= 2.0 YAML based syntax (json no more supported)


0.0.3 (2018-01-22)
------------------

- remove condition option (already implemented by pytest-play's ``skip_condition``)

- documentation improvements


0.0.2 (2018-01-16)
------------------

- Refactor internal methods

- Remove merge commands with default payload (already
  implemented in ``pytest-play`` >= 1.1.0)


0.0.1 (2018-01-10)
------------------

* First release
